@@ -8,12 +8,11 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_lambda._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-triggers", "0.0.212", __name__[0:-6], "cdk-triggers@0.0.212.jsii.tgz"
+    "cdk-triggers", "0.1.2", __name__[0:-6], "cdk-triggers@0.1.2.jsii.tgz"
 )
 
 __all__ = [
